@@ -27,8 +27,13 @@
 #include "pangoft2.h"
 #include "pango-utils.h"
 
+#include "basic-common.h"
+
 #define SCRIPT_ENGINE_NAME "BasicScriptEngineFT2"
 
+#include "basic-common.h"
+
+
 static PangoEngineRange basic_ranges[] = {
   /* Basic Latin, Latin-1 Supplement, Latin Extended-A, Latin Extended-B,
    * IPA Extensions
@@ -212,7 +217,10 @@ basic_engine_shape (PangoFont        *font,
 	if (pango_get_mirror_char (wc, &mirrored_ch))
 	  wc = mirrored_ch;
 
-      if (wc == 0x200B || wc == 0x200E || wc == 0x200F)	/* Zero-width characters */
+      if (wc == 0xa0)	/* non-break-space */
+	wc = 0x20;
+		
+      if (ZERO_WIDTH_CHAR (wc))
 	{
 	  set_glyph (font, glyphs, i, p - text, 0);
 	}
