@@ -25,9 +25,7 @@
 #include <pango/pango-font.h>
 #include <glib-object.h>
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 /* PangoColor */
 
@@ -45,6 +43,8 @@ GType       pango_color_get_type (void) G_GNUC_CONST;
 
 PangoColor *pango_color_copy     (const PangoColor *src);
 void        pango_color_free     (PangoColor       *color);
+gboolean    pango_color_parse    (PangoColor       *color,
+				  const char       *spec);
 
 /* Attributes */
 
@@ -52,6 +52,7 @@ typedef struct _PangoAttribute    PangoAttribute;
 typedef struct _PangoAttrClass    PangoAttrClass;
 				  
 typedef struct _PangoAttrString   PangoAttrString;
+typedef struct _PangoAttrLanguage PangoAttrLanguage;
 typedef struct _PangoAttrInt      PangoAttrInt;
 typedef struct _PangoAttrFloat    PangoAttrFloat;
 typedef struct _PangoAttrColor    PangoAttrColor;
@@ -65,7 +66,7 @@ typedef struct _PangoAttrIterator PangoAttrIterator;
 typedef enum
 {
   PANGO_ATTR_INVALID,           /* 0 is an invalid attribute type */
-  PANGO_ATTR_LANG,		/* PangoAttrString */
+  PANGO_ATTR_LANGUAGE,		/* PangoAttrLanguage */
   PANGO_ATTR_FAMILY,		/* PangoAttrString */
   PANGO_ATTR_STYLE,		/* PangoAttrInt */
   PANGO_ATTR_WEIGHT,		/* PangoAttrInt */
@@ -110,6 +111,12 @@ struct _PangoAttrString
   char *value;
 };
 
+struct _PangoAttrLanguage
+{
+  PangoAttribute attr;
+  PangoLanguage *value;
+};
+
 struct _PangoAttrInt
 {
   PangoAttribute attr;
@@ -138,7 +145,7 @@ struct _PangoAttrShape
 struct _PangoAttrFontDesc
 {
   PangoAttribute attr;
-  PangoFontDescription desc;
+  PangoFontDescription *desc;
 };
 
 PangoAttrType    pango_attr_type_register (const gchar          *name);
@@ -148,7 +155,7 @@ void             pango_attribute_destroy       (PangoAttribute       *attr);
 gboolean         pango_attribute_equal         (const PangoAttribute *attr1,
 						const PangoAttribute *attr2);
 
-PangoAttribute *pango_attr_lang_new          (const char                 *lang);
+PangoAttribute *pango_attr_language_new      (PangoLanguage              *language);
 PangoAttribute *pango_attr_family_new        (const char                 *family);
 PangoAttribute *pango_attr_foreground_new    (guint16                     red,
 					      guint16                     green,
@@ -195,8 +202,8 @@ void               pango_attr_iterator_destroy  (PangoAttrIterator     *iterator
 PangoAttribute *   pango_attr_iterator_get      (PangoAttrIterator     *iterator,
                                                  PangoAttrType          type);
 void               pango_attr_iterator_get_font (PangoAttrIterator     *iterator,
-                                                 PangoFontDescription  *base,
-                                                 PangoFontDescription  *current,
+                                                 PangoFontDescription  *desc,
+						 PangoLanguage        **language,
                                                  GSList               **extra_attrs);
 
 
@@ -208,8 +215,6 @@ gboolean pango_parse_markup (const char                 *markup_text,
                              gunichar                   *accel_char,
                              GError                    **error);
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* __PANGO_ATTRIBUTES_H__ */
